@@ -64,7 +64,7 @@ extern "C"
 
 using namespace libdar;
 
-#define DAR_MANAGER_VERSION "1.8.0"
+#define DAR_MANAGER_VERSION "1.8.1"
 
 
 #define ONLY_ONCE "Only one -%c is allowed, ignoring this extra option"
@@ -343,7 +343,7 @@ static bool command_line(shell_interaction & dialog,
 			throw Erange("command_line", tools_printf(gettext(MISSING_ARG), char(lu)));
 		    line_tools_split_path_basename(optarg, chem, filename);
 		    line_tools_check_basename(dialog, chem, filename, EXTENSION);
-		    arg = (path(chem)+filename).display();
+		    arg = (path(chem).append(filename)).display();
 		    break;
 		case 'l':
 		    if(op != none_op)
