@@ -1,6 +1,6 @@
 /*********************************************************************/
 // dar - disk archive - a backup/restoration program
-// Copyright (C) 2002-2018 Denis Corbin
+// Copyright (C) 2002-2019 Denis Corbin
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -237,7 +237,8 @@ namespace libdar
 		delete crc_calc;
 	}
 
-        stats.add(ret);
+	if(ret != nullptr)
+	    stats.add(ret);
         return ret;
     }
 
@@ -395,6 +396,12 @@ namespace libdar
 		if(tmp_file->get_crc(crc_tmp) && crc_tmp != nullptr)
 		    ent.set_data_crc(*crc_tmp);
 	    }
+
+	    if(tmp_file->has_delta_signature_structure())
+	    {
+		tmp_file->read_delta_signature_metadata();
+		tmp_file->drop_delta_signature_data();
+	    }
 	    ent.set_delta_sig(tmp_file->has_delta_signature_available());
 	    if(tmp_file->has_patch_base_crc() && tmp_file->get_patch_base_crc(crc_tmp) && crc_tmp != nullptr)
 		ent.set_delta_patch_base_crc(*crc_tmp);
