@@ -1,6 +1,6 @@
 /*********************************************************************/
 // dar - disk archive - a backup/restoration program
-// Copyright (C) 2002-2018 Denis Corbin
+// Copyright (C) 2002-2019 Denis Corbin
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -57,7 +57,7 @@ namespace libdar
 	virtual bool operator == (const cat_entree & ref) const override { return true; };
         virtual unsigned char signature() const override { return 'z'; };
 	virtual std::string get_description() const override { return "end of directory"; };
-        cat_entree *clone() const { return new (std::nothrow) cat_eod(); };
+        cat_entree *clone() const override { return new (std::nothrow) cat_eod(); };
 
     };
 
