@@ -1,6 +1,6 @@
 /*********************************************************************/
 // dar - disk archive - a backup/restoration program
-// Copyright (C) 2002-2018 Denis Corbin
+// Copyright (C) 2002-2019 Denis Corbin
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -58,7 +58,7 @@ namespace libdar
 	Egeneric(const Egeneric & ref) = default;
 
 	    /// move constructor
-	Egeneric(Egeneric && ref) noexcept = default;
+	Egeneric(Egeneric && ref) = default;
 
 	    /// assignment operator
 	Egeneric & operator = (const Egeneric & ref) = default;
