@@ -1,6 +1,6 @@
 /*********************************************************************/
 // dar - disk archive - a backup/restoration program
-// Copyright (C) 2002-2018 Denis Corbin
+// Copyright (C) 2002-2019 Denis Corbin
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -187,7 +187,8 @@ namespace libdar
 
 	if(ref_file != nullptr)
 	{
-	    if(ref_file->get_saved_status() == saved_status::saved)
+	    if(ref_file->get_saved_status() == saved_status::saved
+	       || ref_file->get_saved_status() == saved_status::delta)
 	    {
 		const crc * c = nullptr;
 
