@@ -1,6 +1,6 @@
 /*********************************************************************/
 // dar - disk archive - a backup/restoration program
-// Copyright (C) 2002-2018 Denis Corbin
+// Copyright (C) 2002-2019 Denis Corbin
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -56,7 +56,7 @@ namespace libdar
 	      bool cache_directory_tagging,
 	      bool furtive_read_mode);
 	etage(const etage & ref) = default;
-	etage(etage && ref) noexcept = default;
+	etage(etage && ref) = default;
 	etage & operator = (const etage & ref) = default;
 	etage & operator = (etage && ref) noexcept = default;
 	~etage() = default;
