@@ -133,7 +133,7 @@ namespace libdar
 
     cat_nomme *filesystem_hard_link_read::make_read_entree(const path & lieu, const string & name, bool see_hard_link, const mask & ea_mask)
     {
-	const string display = name.empty() ? lieu.display() : (lieu + name).display();
+	const string display = name.empty() ? lieu.display() : (lieu.append(name)).display();
         const char *ptr_name = display.c_str();
         cat_nomme *ref = nullptr;
 	struct stat buf;
