@@ -223,7 +223,7 @@ namespace libdar
 	    {
 		if(!empty && stack_dir.back().get_restore_date())
 		{
-		    string chem = (*current_dir + stack_dir.back().get_name()).display();
+		    string chem = (current_dir->append(stack_dir.back().get_name())).display();
 		    filesystem_tools_make_date(stack_dir.back(), chem, what_to_check, get_fsa_scope());
 		    filesystem_tools_make_owner_perm(get_ui(), stack_dir.back(), chem, what_to_check, get_fsa_scope());
 		}
@@ -243,7 +243,7 @@ namespace libdar
 	    bool has_just_inode = x_ino != nullptr && x_ino->get_saved_status() == saved_status::inode_only;
 	    bool has_ea_saved = x_ino != nullptr && (x_ino->ea_get_saved_status() == ea_saved_status::full || x_ino->ea_get_saved_status() == ea_saved_status::removed);
 	    bool has_fsa_saved = x_ino != nullptr && x_ino->fsa_get_saved_status() == fsa_saved_status::full;
-	    path spot = *current_dir + x_nom->get_name();
+	    path spot = current_dir->append(x_nom->get_name());
 	    string spot_display = spot.display();
 
 	    cat_nomme *exists = nullptr;
@@ -306,6 +306,8 @@ namespace libdar
 			if(info_details)
 			    get_ui().message(string(gettext("Restoring file's data: ")) + spot_display);
 
+			    // 1 - restoring data
+
 			if(!empty)
 			    make_file(x_nom, *current_dir);
 			data_created = true;
@@ -318,6 +320,8 @@ namespace libdar
 			    // we must try to restore EA or FSA only if data could be restored
 			    // as in the current situation no file existed before
 
+			    // 2 - restoring EA
+
 			if(has_ea_saved)
 			{
 			    if(info_details)
@@ -339,6 +343,8 @@ namespace libdar
 				ea_restored = true;
 			}
 
+			    // 3 - restoring FSA (including Mac OSX birth date if present)
+
 			if(has_fsa_saved)
 			{
 			    if(info_details)
@@ -369,10 +375,18 @@ namespace libdar
 			    // be met
 			if(!empty && x_dir == nullptr && x_ino != nullptr)
 			{
+				// 4 - restoring dates
+
 			    filesystem_tools_make_date(*x_ino,
 						       spot_display,
 						       what_to_check,
 						       get_fsa_scope());
+
+				// 5 - restoring permission and ownership
+				// first system may have removed linux capabilities (part of EA)
+				// due to change of ownership,
+				// second, if dar is not run as root, we may fail any further operation on
+				// this file so we must not report failure if subsenquent action fails
 			    filesystem_tools_make_owner_perm(get_ui(),
 							     *x_ino,
 							     spot_display,
@@ -380,7 +394,24 @@ namespace libdar
 							     get_fsa_scope());
 			}
 
-			    // Last: setting the linux immutable flag if present
+			    // 6 - trying re-setting EA after awnership restoration to set back linux capabilities
+
+			if(has_ea_saved && !empty)
+			{
+			    const ea_attributs *ea = x_ino->get_ea();
+			    try
+			    {
+				raw_set_ea(x_nom, *ea, spot_display, *ea_mask);
+			    }
+			    catch(Erange & e)
+			    {
+				    // error probably due to permission context,
+				    // as raw_set_ea() has been called earlier
+				    // and either no error met or same error met
+			    }
+			}
+
+			    // 7 - setting the linux immutable flag if present
 
 			if(has_fsa_saved)
 			{
@@ -416,6 +447,8 @@ namespace libdar
 		    over_action_data act_data = data_undefined;
 		    over_action_ea act_ea = EA_undefined;
 
+			// 1 - restoring data
+
 		    overwrite->get_action(*exists, *x_nom, act_data, act_ea);
 
 		    if(x_ino == nullptr)
@@ -476,6 +509,8 @@ namespace libdar
 			    // it will modify EA of the existing file
 			if(act_data != data_remove)
 			{
+				// 2 - restoring EA
+
 			    if(has_ea_saved)
 			    {
 				try
@@ -488,6 +523,8 @@ namespace libdar
 				}
 			    }
 
+				// 3 - restoring FSA
+
 			    if(has_fsa_saved)
 			    {
 				try
@@ -501,6 +538,8 @@ namespace libdar
 			    }
 			}
 
+			    // if we can restore metadata on something (existing inode)
+
 			if(has_fsa_saved || has_ea_saved || has_patch || has_data_saved || has_just_inode)
 			{
 			    if(data_restored == done_data_restored)
@@ -510,12 +549,18 @@ namespace libdar
 			    {
 				if(exists_dir == nullptr)
 				{
+					// 4 - restoring dates (birthtime has been restored with EA)
+
 				    filesystem_tools_make_date(*x_ino,
 							       spot_display,
 							       what_to_check,
 							       get_fsa_scope());
-					// setting ownership as last step as it can lead us not
-					// having anymore right on the file
+
+					// 5 - restoring owership and permission with two consequences :
+					// - system erased linux capabilites (EA)
+					// - may not be able to restore further and must not propagate failures
+					// for subnsequent steps
+
 				    filesystem_tools_make_owner_perm(get_ui(),
 								     *x_ino,
 								     spot_display,
@@ -532,6 +577,28 @@ namespace libdar
 							   get_fsa_scope());
 			}
 
+			    // 6 - restoring linux capabilities if possible
+
+			if(ea_restored)
+			{
+				// if linux capabilities were restored, changing ownership let them
+				// been removed by the system. And doing restoration of EA after ownership
+				// may avoid being able to restore EA due to lack of privilege if
+				// libdar is not ran as root
+			    try
+			    {
+				(void)action_over_ea(exists_ino, x_nom, spot_display, act_ea);
+			    }
+			    catch(Erange & e)
+			    {
+				    // ignoring any error here
+				    // we already restored EA
+				    // previously
+			    }
+			}
+
+			    // 7 - restoring linux immutable FSA if present
+
 			if(fsa_restored)
 			{
 			    if(!empty)
@@ -1141,7 +1208,7 @@ namespace libdar
 
 	while(!stack_dir.empty() && current_dir->pop(tmp))
 	{
-	    string chem = (*current_dir + stack_dir.back().get_name()).display();
+	    string chem = (current_dir->append(stack_dir.back().get_name())).display();
 	    if(!empty)
 		filesystem_tools_make_owner_perm(get_ui(), stack_dir.back(), chem, what_to_check, get_fsa_scope());
 	    stack_dir.pop_back();
