@@ -1,6 +1,6 @@
 /*********************************************************************/
 // dar - disk archive - a backup/restoration program
-// Copyright (C) 2002-2018 Denis Corbin
+// Copyright (C) 2002-2019 Denis Corbin
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -61,7 +61,7 @@ namespace libdar
     public:
 	list_entry() { clear(); };
 	list_entry(const list_entry & ref) = default;
-	list_entry(list_entry && ref) noexcept = default;
+	list_entry(list_entry && ref) = default;
 	list_entry & operator = (const list_entry & ref) = default;
 	list_entry & operator = (list_entry && ref) noexcept = default;
 	~list_entry() = default;
