@@ -1,6 +1,6 @@
 /*********************************************************************/
 // dar - disk archive - a backup/restoration program
-// Copyright (C) 2002-2018 Denis Corbin
+// Copyright (C) 2002-2019 Denis Corbin
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -62,7 +62,7 @@ namespace libdar
 	    /// \param[in] include whether the mask_list is used for file inclusion or file exclusion
         mask_list(const std::string & filename_list_st, bool case_sensit, const path & prefix, bool include);
 	mask_list(const mask_list & ref) = default;
-	mask_list(mask_list && ref) noexcept = default;
+	mask_list(mask_list && ref) = default;
 	mask_list & operator = (const mask_list & ref) = default;
 	mask_list & operator = (mask_list && ref) noexcept = default;
 	~mask_list() = default;
