@@ -1,6 +1,6 @@
 /*********************************************************************/
 // dar - disk archive - a backup/restoration program
-// Copyright (C) 2002-2018 Denis Corbin
+// Copyright (C) 2002-2019 Denis Corbin
 //
 // This program is free software; you can redistribute it and/or
 // modify it under the terms of the GNU General Public License
@@ -150,8 +150,8 @@ namespace libdar
 	virtual bool skip_relative(S_I x) override;
 	virtual infinint get_position() const override;
 
-	void copy_to(generic_file & ref);
-	void copy_to(generic_file & ref, const infinint & crc_size, crc * & value);
+	void copy_to(generic_file & ref) override;
+	void copy_to(generic_file & ref, const infinint & crc_size, crc * & value) override;
 
     protected:
 	virtual void inherited_read_ahead(const infinint & amount) override;
